# Omnis
Deep Learning for everyone

------------------


## You have just found Omnis.

Omnis is an API of neural network applications, written in Python and capable of running on top of [Keras](https://github.com/keras-team/keras). It was developed with a focus on enabling fast application of deep learning.

Use Omnis if you need a deep learning library that:

- Is EASY to learn and use.
- Allows for easy and fast prototyping.
- Supports CNN, RNN, GAN, RL and etc.(TBA)
- Runs seamlessly on CPU and GPU.

Omnis is compatible with: __Python 2.7-3.6__.

------------------


## Guiding principles

- __Simplicity.__ Omnis pursues a simple architecture. Designing a software with simple architecture not only helps you to understand the code easily but also helps your painful debugging.

- __Easiness.__ Don't worry about complicated algorithms or theories or mathematics. Omnis will handle difficult stuffs for you. Just learn how to use deep neural network and USE THIS!

- __Modularity.__ No spaghetti code!

------------------


## Why this name, Omnis?

Omnis means _EVERY_ in Latin. The goal of Omnis is to make deep learning technologies easier so that _EVERY_ one can use deep learning technologies without headache.

------------------
